@@ -1,6 +1,6 @@
+import eons
 import os
 import logging
-import eons
 from pathlib import Path
 import jsonpickle
 import yaml
@@ -43,7 +43,7 @@ class EBBS(eons.Executor):
 		super().Configure()
 
 		this.defaultBuildIn = "build"
-		this.defaultConfigFile = "build"
+		this.defaultConfigFile = "config"
 		this.defaultPackageType = "build"
 		this.defaultPrefix = "build" # DEPRECATED
 
@@ -93,8 +93,8 @@ class EBBS(eons.Executor):
 	#Override of eons.Executor method. See that class for details
 	def Function(this):
 		super().Function()
-				
-		return this.Build(this.parsedArgs.builder, this.parsedArgs.path, this.defaultBuildIn, this.events, **this.extraArgs)
+		build = this.Fetch('build', default="default")
+		return this.Build(build, this.parsedArgs.path, this.defaultBuildIn, this.events, **this.extraArgs)
 
 	#Run a build script.
 	#RETURNS whether or not the build was successful.
@@ -177,8 +177,8 @@ class Builder(eons.StandardFunctor):
 
 		if (rootPath is None):
 			logging.warning("no \"dir\" supplied. Paths unavailable.")
-			this.rootPath = ""
-			this.buildPath = ""
+			this.rootPath = None
+			this.buildPath = None
 			for path in paths:
 				setattr(this, f"{path}Path", None)
 			return
@@ -239,11 +239,12 @@ class Builder(eons.StandardFunctor):
 		if ('path' in this.kwargs and 'build_in' in this.kwargs):
 			this.PopulatePaths(this.kwargs.pop('path'), this.kwargs.pop('build_in'))
 			this.PopulateLocalConfig()
+			details = os.path.basename(this.rootPath).split(".")
 		else:
 			this.PopulatePaths(None, None)
 			this.config = None
+			details = [this.name]
 
-		details = os.path.basename(this.rootPath).split(".")
 		default_type = details[-1]
 		default_name = default_type
 		if (len(details) > 1):
@@ -300,6 +301,9 @@ class Builder(eons.StandardFunctor):
 	# Creates the folder structure for the next build step.
 	# RETURNS the next buildPath.
 	def PrepareNext(this, nextBuilder):
+		if (not this.buildPath):
+			return None
+
 		logging.debug(f"<---- Preparing for next builder: {nextBuilder['build']} ---->")
 		# logging.debug(f"Preparing for next builder: {nextBuilder}")
 
@@ -368,12 +372,13 @@ class Builder(eons.StandardFunctor):
 	def Function(this):
 		logging.debug(f"<---- Preparing {this.name} ---->")
 
-		if (this.clearBuildPath):
-			this.Delete(this.buildPath)
+		if (this.buildPath):
+			if (this.clearBuildPath):
+				this.Delete(this.buildPath)
 
-		# mkpath(this.buildPath) <- This just straight up doesn't work. Race condition???
-		Path(this.buildPath).mkdir(parents=True, exist_ok=True)
-		os.chdir(this.buildPath)
+			# mkpath(this.buildPath) <- This just straight up doesn't work. Race condition???
+			Path(this.buildPath).mkdir(parents=True, exist_ok=True)
+			os.chdir(this.buildPath)
 
 		this.PreBuild()
 
@@ -384,9 +389,11 @@ class Builder(eons.StandardFunctor):
 		logging.debug(f">---- Done Preparing {this.name} ----<")
 
 		runMessage = f"Building {this.name}"
-		if (len(this.projectName)):
-			runMessage += f"for \"{this.projectName}\", a \"{this.projectType}\""
-		if (len(this.buildPath)):
+		if (this.projectName):
+			runMessage += f" for \"{this.projectName}\""
+		if (this.projectType != this.projectName):
+			runMessage += f", a \"{this.projectType}\""
+		if (this.buildPath):
 			runMessage += f"in {this.buildPath}"
 		logging.info(runMessage)
 
